@@ -21,22 +21,23 @@ class SystemBars(webdriver.Remote):
 
     def get_system_bars(self):
         """Retrieve visibility and bounds information of the status and navigation bars.
+
         Android only.
 
-        :return:
-        A dictionary whose keys are
-         - statusBar
-           - visible
-           - x
-           - y
-           - width
-           - height
-         - navigationBar
-           - visible
-           - x
-           - y
-           - width
-           - height
+        Returns:
+            A dictionary whose keys are
+             - statusBar
+               - visible
+               - x
+               - y
+               - width
+               - height
+             - navigationBar
+               - visible
+               - x
+               - y
+               - width
+               - height
         """
         return self.execute(Command.GET_SYSTEM_BARS)['value']
 
