@@ -13,6 +13,7 @@
 # limitations under the License.
 
 from selenium.webdriver.common.by import By
+from selenium.webdriver.common.utils import keys_to_typing
 from selenium.webdriver.remote.command import Command as RemoteCommand
 
 from .extensions.search_context import AppiumWebElementSearchContext
@@ -204,3 +205,18 @@ class WebElement(AppiumWebElementSearchContext):
         }
         self._execute(Command.SET_IMMEDIATE_VALUE, data)
         return self
+
+    # Override
+    def send_keys(self, *value):
+        """Simulates typing into the element.
+
+        Args:
+            value (str): A string for typing.
+
+        Returns:
+            `appium.webdriver.webelement.WebElement`
+        """
+        keys = keys_to_typing(value)
+        self._execute(RemoteCommand.SEND_KEYS_TO_ELEMENT,
+                      {'text': ''.join(keys), 'value': keys})
+        return self
